"""ghorse._phorse.functional: Functional interface for ghorse."""

from ghorse._ghorse import Graph


def number_of_nodes(graph: Graph) -> int:
    # TODO: docstring
    return graph.number_of_nodes()



"""ghorse: Python graph C extension."""

__all__ = [
    # functions
    "freeze",
    "number_of_nodes",
    # classes
    "Graph",
]

from ghorse._ghorse import Graph, freeze
from ghorse._functional import number_of_nodes



# noqa

from setuptools import Extension, setup

ghorse_sources = [
    "ghorse/_ghorse/src/" + name for name in ["module.c", "freeze.c", "graph.c"]
]

ghorse_extension = Extension(
    name="ghorse._ghorse",
    sources=ghorse_sources,
    include_dirs=["ghorse/_ghorse/include"],
    define_macros=[("PY_SSIZE_T_CLEAN", None)],
)

setup(
    name="ghorse",
    packages=["ghorse"],
    ext_modules=[ghorse_extension],
)
